export interface IPageProps {
    title?: string;
    style?: string[];
    script?: string[];
    headScript?: string[];
    meta?: IHTMLMetaElement[];
    link?: IHTMLLinkElement[];
    envName?: string;
    startupDate?: Date;
    cdn?: string;
    staticURL?: string;
    cdnServer?: string;
}
export interface IHTMLMetaElement {
    /**
     * Sets or retrieves the character set used to encode the object.
     */
    charset?: string;
    /**
     * Gets or sets meta-information to associate with httpEquiv or name.
     */
    content?: string;
    /**
     * Gets or sets information used to bind the value of a content attribute of a meta element
     * to an HTTP response header.
     */
    httpEquiv?: string;
    /**
     * Sets or retrieves the value specified in the content attribute of the meta object.
     */
    name?: string;
    /**
     * Sets or retrieves a scheme to be used in interpreting the value of a property specified for the object.
     */
    scheme?: string;
    /**
     * Sets or retrieves the URL property that will be loaded after the specified time has elapsed.
     */
    url?: string;
    key?: string;
}
export interface IHTMLLinkElement {
    /**
     * Sets or retrieves the character set used to encode the object.
     */
    charset?: string;
    disabled?: boolean;
    /**
     * Sets or retrieves a destination URL or an anchor point.
     */
    href?: string;
    /**
     * Sets or retrieves the language code of the object.
     */
    hreflang?: string;
    /**
     * Sets or retrieves the media type.
     */
    media?: string;
    /**
     * Sets or retrieves the relationship between the object and the destination of the link.
     */
    rel?: string;
    /**
     * Sets or retrieves the relationship between the object and the destination of the link.
     */
    rev?: string;
    /**
     * Sets or retrieves the window or frame at which to target content.
     */
    target?: string;
    /**
     * Sets or retrieves the MIME type of the object.
     */
    type?: string;
    import?: Document;
    integrity?: string;
    key?: string;
}
export interface IPageProps {
    title?: string;
    style?: string[];
    script?: string[];
    headScript?: string[];
    meta?: IHTMLMetaElement[];
    link?: IHTMLLinkElement[];
    envName?: string;
    startupDate?: Date;
    cdn?: string;
}
