/// <reference types="react" />
import * as React from "react";
import { Controller } from "../../Controller";
import { IHTMLLinkElement, IHTMLMetaElement } from "./HTMLDto";
import { Page } from "./Page";
export declare class ReactPageController extends Controller {
    title: any;
    script: string[];
    style: string[];
    headScript: any[];
    meta: IHTMLMetaElement[];
    link: IHTMLLinkElement[];
    page: typeof Page;
    private props;
    private data;
    constructor(request: any, response: any, next: any);
    /**
     * 设置网页标题
     * @param title 网页标题
     */
    setTitle(title: string): void;
    /**
     * 添加meta
     * @param meta
     */
    addMeta(meta: IHTMLMetaElement): void;
    /**
     * 添加link
     * @param link
     */
    addLink(link: IHTMLLinkElement): void;
    /**
     * 设置setViewPort
     * @param content 可不填写，默认为"width=device-width, initial-scale=1, maximum-scale=1"
     */
    setViewPort(content?: string): void;
    /**
     * 设置控制器使用的用于渲染Page组件的属性
     * @param {object} data 用于渲染Page组件的属性
     * @return {Controller} 返回实例化后的控制器对象
     */
    setData(data: any): this;
    /**
     * 配置当前控制器使用的脚本
     * @param {string[]} script 配置当前控制器使用的脚本
     */
    setScript(script: string[]): void;
    /**
     * 获得当前设置的控制器数据
     * @return {object} 控制器的数据 default {}
     */
    getData(): {};
    /**
     * 设置控制器使用的页面
     * @param {Component} page React Page组件
     * @return {Controller} 返回实例化后的控制器对象
     */
    setPage(page: any): this;
    /**
     * 获得控制器使用的页面
     * @return {Component} React Page组件
     */
    getPage(): typeof Page;
    /**
     * 设置页面的属性
     */
    setProps(props: any): this;
    /**
     * 获得页面的属性
     */
    getProps(): {};
    /**
     * 给页面添加脚本
     * 如果第二个参数为true，则意味着不使用cdn，直接使用第一个参数作为地址
     * @param script 需要加载的脚本的URI
     * @param local 是否为站内脚本
     */
    addScript(href: string, remote?: boolean): this;
    /**
     * @param script 需要加载的脚本的URI
     * @param local 是否为站内脚本
     */
    addHeadScript(href: string, remote?: boolean): this;
    /**
     * 给页面添加样式
     */
    addStyle(href: string, remote?: boolean): this;
    /**
     * 渲染页面
     */
    render(view?: React.Component<any, any> | any, data?: any): void;
}
